@@ -25,11 +25,11 @@
 #include <KComboBox>
 #include <KConfig>
 #include <KVBox>
-#include <KFontComboBox>
+#include <QFontComboBox>
 #include <KConfigGroup>
 #include <KSharedConfig>
 #include <KLocalizedString>
-#include <KNumInput>
+#include <QSpinBox>
 
 #include <khtmldefaults.h>
 
@@ -37,26 +37,35 @@
 #include <QLabel>
 #include <QLayout>
 #include <qfontdatabase.h>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 using namespace KHC;
 
 FontDialog::FontDialog( QWidget *parent )
-	: KDialog( parent )
+	: QDialog( parent )
 {
   setModal( true );
-  setCaption( i18n( "Font Configuration" ) );
-  setButtons( Ok | Cancel );
+  setWindowTitle( i18n( "Font Configuration" ) );
+  QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel);
+  QVBoxLayout *mainLayout = new QVBoxLayout;
+  setLayout(mainLayout);
+  QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+  okButton->setDefault(true);
+  okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+  connect(buttonBox, SIGNAL(accepted()), this, SLOT(slotOk()));
+  connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
   m_mainWidget = new KVBox( this );
-  setMainWidget( m_mainWidget );
+  mainLayout->addWidget(m_mainWidget);
+  mainLayout->addWidget(buttonBox);
 
   setupFontSizesBox();
   setupFontTypesBox();
   setupFontEncodingBox();
 
   load();
-
-  connect( this, SIGNAL( okClicked() ), SLOT( slotOk() ) );
 }
 
 void FontDialog::slotOk()
@@ -70,19 +79,19 @@ void FontDialog::setupFontSizesBox()
   QGroupBox *gb = new QGroupBox( i18n( "Sizes" ), m_mainWidget );
 
   QGridLayout *layout = new QGridLayout( gb );
-  layout->setSpacing( KDialog::spacingHint() );
-  layout->setMargin( KDialog::marginHint() * 2 );
+//TODO PORT QT5   layout->setSpacing( QDialog::spacingHint() );
+//TODO PORT QT5   layout->setMargin( QDialog::marginHint() * 2 );
 
   QLabel *lMinFontSize = new QLabel( i18nc( "The smallest size a will have", "M&inimum font size:" ), gb );
   layout->addWidget( lMinFontSize, 0, 0 );
-  m_minFontSize = new KIntNumInput( gb );
+  m_minFontSize = new QSpinBox( gb );
   layout->addWidget( m_minFontSize, 0, 1 );
   m_minFontSize->setRange( 1, 20 );
   lMinFontSize->setBuddy( m_minFontSize );
 
   QLabel *lMedFontSize = new QLabel( i18nc( "The normal size a font will have", "M&edium font size:" ), gb );
   layout->addWidget( lMedFontSize, 1, 0 );
-  m_medFontSize = new KIntNumInput( gb );
+  m_medFontSize = new QSpinBox( gb );
   layout->addWidget( m_medFontSize, 1, 1 );
   m_medFontSize->setRange( 4, 28 );
   lMedFontSize->setBuddy( m_medFontSize );
@@ -93,42 +102,42 @@ void FontDialog::setupFontTypesBox()
   QGroupBox *gb = new QGroupBox( i18n( "Fonts" ), m_mainWidget );
 
   QGridLayout *layout = new QGridLayout( gb );
-  layout->setSpacing( KDialog::spacingHint() );
-  layout->setMargin( KDialog::marginHint() * 2 );
+//TODO PORT QT5   layout->setSpacing( QDialog::spacingHint() );
+//TODO PORT QT5   layout->setMargin( QDialog::marginHint() * 2 );
 
   QLabel *lStandardFont = new QLabel( i18n( "S&tandard font:" ), gb );
   layout->addWidget( lStandardFont, 0, 0 );
-  m_standardFontCombo = new KFontComboBox( gb );
+  m_standardFontCombo = new QFontComboBox( gb );
   layout->addWidget( m_standardFontCombo, 0, 1 );
   lStandardFont->setBuddy( m_standardFontCombo );
 
   QLabel *lFixedFont = new QLabel( i18n( "F&ixed font:" ), gb );
   layout->addWidget( lFixedFont, 1, 0 );
-  m_fixedFontCombo = new KFontComboBox( gb );
+  m_fixedFontCombo = new QFontComboBox( gb );
   layout->addWidget( m_fixedFontCombo, 1, 1 );
   lFixedFont->setBuddy( m_fixedFontCombo );
 
   QLabel *lSerifFont = new QLabel( i18n( "S&erif font:" ), gb );
   layout->addWidget( lSerifFont, 2, 0 );
-  m_serifFontCombo = new KFontComboBox( gb );
+  m_serifFontCombo = new QFontComboBox( gb );
   layout->addWidget( m_serifFontCombo, 2, 1 );
   lSerifFont->setBuddy( m_serifFontCombo );
 
   QLabel *lSansSerifFont = new QLabel( i18n( "S&ans serif font:" ), gb );
   layout->addWidget( lSansSerifFont, 3, 0 );
-  m_sansSerifFontCombo = new KFontComboBox( gb );
+  m_sansSerifFontCombo = new QFontComboBox( gb );
   layout->addWidget( m_sansSerifFontCombo, 3, 1 );
   lSansSerifFont->setBuddy( m_sansSerifFontCombo );
 
   QLabel *lItalicFont = new QLabel( i18n( "&Italic font:" ), gb );
   layout->addWidget( lItalicFont, 4, 0 );
-  m_italicFontCombo = new KFontComboBox( gb );
+  m_italicFontCombo = new QFontComboBox( gb );
   layout->addWidget( m_italicFontCombo, 4, 1 );
   lItalicFont->setBuddy( m_italicFontCombo );
 
   QLabel *lFantasyFont = new QLabel( i18n( "&Fantasy font:" ), gb );
   layout->addWidget( lFantasyFont, 5, 0 );
-  m_fantasyFontCombo = new KFontComboBox( gb );
+  m_fantasyFontCombo = new QFontComboBox( gb );
   layout->addWidget( m_fantasyFontCombo, 5, 1 );
   lFantasyFont->setBuddy( m_fantasyFontCombo );
 }
@@ -138,8 +147,8 @@ void FontDialog::setupFontEncodingBox()
   QGroupBox *gb = new QGroupBox( i18n( "Encoding" ), m_mainWidget );
 
   QGridLayout *layout = new QGridLayout( gb );
-  layout->setSpacing( KDialog::spacingHint() );
-  layout->setMargin( KDialog::marginHint() * 2 );
+//TODO PORT QT5   layout->setSpacing( QDialog::spacingHint() );
+//TODO PORT QT5   layout->setMargin( QDialog::marginHint() * 2 );
 
   QLabel *lDefaultEncoding = new QLabel( i18n( "&Default encoding:" ), gb );
   layout->addWidget( lDefaultEncoding, 0, 0 );
@@ -152,7 +161,7 @@ void FontDialog::setupFontEncodingBox()
 
   QLabel *lFontSizeAdjustement = new QLabel( i18n( "&Font size adjustment:" ), gb );
   layout->addWidget( lFontSizeAdjustement, 1, 0 );
-  m_fontSizeAdjustement = new KIntSpinBox( gb );
+  m_fontSizeAdjustement = new QSpinBox( gb );
   m_fontSizeAdjustement->setRange( -5, 5 );
   m_fontSizeAdjustement->setSingleStep( 1 );
   layout->addWidget( m_fontSizeAdjustement, 1, 1 );
@@ -225,5 +234,4 @@ void FontDialog::save()
   cfg->sync();
 }
 
-#include "fontdialog.moc"
 // vim:ts=4:sw=4:noet
